_**by Edgar Allan Poe**  
(published 1850)_

    

IN THE consideration of the faculties and impulses -- of the prima mobilia of the human soul, the phrenologists have failed to make room for a propensity which, although obviously existing as a radical, primitive, irreducible sentiment, has been equally overlooked by all the moralists who have preceded them. In the pure arrogance of the reason, we have all overlooked it. We have suffered its existence to escape our senses, solely through want of belief -- of faith; -- whether it be faith in Revelation, or faith in the Kabbala. The idea of it has never occurred to us, simply because of its supererogation. We saw no need of the impulse -- for the propensity. We could not perceive its necessity. We could not understand, that is to say, we could not have understood, had the notion of this primum mobile ever obtruded itself; -- we could not have understood in what manner it might be made to further the objects of humanity, either temporal or eternal. It cannot be denied that phrenology and, in great measure, all metaphysicianism have been concocted a priori. The intellectual or logical man, rather than the understanding or observant man, set himself to imagine designs -- to dictate purposes to God. Having thus fathomed, to his satisfaction, the intentions of Jehovah, out of these intentions he built his innumerable systems of mind. In the matter of phrenology, for example, we first determined, naturally enough, that it was the design of the Deity that man should eat. We then assigned to man an organ of alimentiveness, and this organ is the scourge with which the Deity compels man, will-I nill-I, into eating. Secondly, having settled it to be God's will that man should continue his species, we discovered an organ of amativeness, forthwith. And so with combativeness, with ideality, with causality, with constructiveness, -- so, in short, with every organ, whether representing a propensity, a moral sentiment, or a faculty of the pure intellect. And in these arrangements of the Principia of human action, the Spurzheimites, whether right or wrong, in part, or upon the whole, have but followed, in principle, the footsteps of their predecessors: deducing and establishing every thing from the preconceived destiny of man, and upon the ground of the objects of his Creator.  
  
It would have been wiser, it would have been safer, to classify (if classify we must) upon the basis of what man usually or occasionally did, and was always occasionally doing, rather than upon the basis of what we took it for granted the Deity intended him to do. If we cannot comprehend God in his visible works, how then in his inconceivable thoughts, that call the works into being? If we cannot understand him in his objective creatures, how then in his substantive moods and phases of creation?  
  
Induction, a posteriori, would have brought phrenology to admit, as an innate and primitive principle of human action, a paradoxical something, which we may call perverseness, for want of a more characteristic term. In the sense I intend, it is, in fact, a mobile without motive, a motive not motivirt. Through its promptings we act without comprehensible object; or, if this shall be understood as a contradiction in terms, we may so far modify the proposition as to say, that through its promptings we act, for the reason that we should not. In theory, no reason can be more unreasonable, but, in fact, there is none more strong. With certain minds, under certain conditions, it becomes absolutely irresistible. I am not more certain that I breathe, than that the assurance of the wrong or error of any action is often the one unconquerable force which impels us, and alone impels us to its prosecution. Nor will this overwhelming tendency to do wrong for the wrong's sake, admit of analysis, or resolution into ulterior elements. It is a radical, a primitive impulse-elementary. It will be said, I am aware, that when we persist in acts because we feel we should not persist in them, our conduct is but a modification of that which ordinarily springs from the combativeness of phrenology. But a glance will show the fallacy of this idea. The phrenological combativeness has for its essence, the necessity of self-defence. It is our safeguard against injury. Its principle regards our well-being; and thus the desire to be well is excited simultaneously with its development. It follows, that the desire to be well must be excited simultaneously with any principle which shall be merely a modification of combativeness, but in the case of that something which I term perverseness, the desire to be well is not only not aroused, but a strongly antagonistical sentiment exists.  
  
An appeal to one's own heart is, after all, the best reply to the sophistry just noticed. No one who trustingly consults and thoroughly questions his own soul, will be disposed to deny the entire radicalness of the propensity in question. It is not more incomprehensible than distinctive. There lives no man who at some period has not been tormented, for example, by an earnest desire to tantalize a listener by circumlocution. The speaker is aware that he displeases; he has every intention to please, he is usually curt, precise, and clear, the most laconic and luminous language is struggling for utterance upon his tongue, it is only with difficulty that he restrains himself from giving it flow; he dreads and deprecates the anger of him whom he addresses; yet, the thought strikes him, that by certain involutions and parentheses this anger may be engendered. That single thought is enough. The impulse increases to a wish, the wish to a desire, the desire to an uncontrollable longing, and the longing (to the deep regret and mortification of the speaker, and in defiance of all consequences) is indulged.  
  
We have a task before us which must be speedily performed. We know that it will be ruinous to make delay. The most important crisis of our life calls, trumpet-tongued, for immediate energy and action. We glow, we are consumed with eagerness to commence the work, with the anticipation of whose glorious result our whole souls are on fire. It must, it shall be undertaken to-day, and yet we put it off until to-morrow, and why? There is no answer, except that we feel perverse, using the word with no comprehension of the principle. To-morrow arrives, and with it a more impatient anxiety to do our duty, but with this very increase of anxiety arrives, also, a nameless, a positively fearful, because unfathomable, craving for delay. This craving gathers strength as the moments fly. The last hour for action is at hand. We tremble with the violence of the conflict within us, -- of the definite with the indefinite -- of the substance with the shadow. But, if the contest have proceeded thus far, it is the shadow which prevails, -- we struggle in vain. The clock strikes, and is the knell of our welfare. At the same time, it is the chanticleer -- note to the ghost that has so long overawed us. It flies -- it disappears -- we are free. The old energy returns. We will labor now. Alas, it is too late!  
  
We stand upon the brink of a precipice. We peer into the abyss -- we grow sick and dizzy. Our first impulse is to shrink from the danger. Unaccountably we remain. By slow degrees our sickness and dizziness and horror become merged in a cloud of unnamable feeling. By gradations, still more imperceptible, this cloud assumes shape, as did the vapor from the bottle out of which arose the genius in the Arabian Nights. But out of this our cloud upon the precipice's edge, there grows into palpability, a shape, far more terrible than any genius or any demon of a tale, and yet it is but a thought, although a fearful one, and one which chills the very marrow of our bones with the fierceness of the delight of its horror. It is merely the idea of what would be our sensations during the sweeping precipitancy of a fall from such a height. And this fall -- this rushing annihilation -- for the very reason that it involves that one most ghastly and loathsome of all the most ghastly and loathsome images of death and suffering which have ever presented themselves to our imagination -- for this very cause do we now the most vividly desire it. And because our reason violently deters us from the brink, therefore do we the most impetuously approach it. There is no passion in nature so demoniacally impatient, as that of him who, shuddering upon the edge of a precipice, thus meditates a Plunge. To indulge, for a moment, in any attempt at thought, is to be inevitably lost; for reflection but urges us to forbear, and therefore it is, I say, that we cannot. If there be no friendly arm to check us, or if we fail in a sudden effort to prostrate ourselves backward from the abyss, we plunge, and are destroyed.  
  
Examine these similar actions as we will, we shall find them resulting solely from the spirit of the Perverse. We perpetrate them because we feel that we should not. Beyond or behind this there is no intelligible principle; and we might, indeed, deem this perverseness a direct instigation of the Arch-Fiend, were it not occasionally known to operate in furtherance of good.  
  
I have said thus much, that in some measure I may answer your question, that I may explain to you why I am here, that I may assign to you something that shall have at least the faint aspect of a cause for my wearing these fetters, and for my tenanting this cell of the condemned. Had I not been thus prolix, you might either have misunderstood me altogether, or, with the rabble, have fancied me mad. As it is, you will easily perceive that I am one of the many uncounted victims of the Imp of the Perverse.  
  
It is impossible that any deed could have been wrought with a more thorough deliberation. For weeks, for months, I pondered upon the means of the murder. I rejected a thousand schemes, because their accomplishment involved a chance of detection. At length, in reading some French Memoirs, I found an account of a nearly fatal illness that occurred to Madame Pilau, through the agency of a candle accidentally poisoned. The idea struck my fancy at once. I knew my victim's habit of reading in bed. I knew, too, that his apartment was narrow and ill-ventilated. But I need not vex you with impertinent details. I need not describe the easy artifices by which I substituted, in his bed-room candle-stand, a wax-light of my own making for the one which I there found. The next morning he was discovered dead in his bed, and the Coroner's verdict was -- "Death by the visitation of God."  
  
Having inherited his estate, all went well with me for years. The idea of detection never once entered my brain. Of the remains of the fatal taper I had myself carefully disposed. I had left no shadow of a clew by which it would be possible to convict, or even to suspect me of the crime. It is inconceivable how rich a sentiment of satisfaction arose in my bosom as I reflected upon my absolute security. For a very long period of time I was accustomed to revel in this sentiment. It afforded me more real delight than all the mere worldly advantages accruing from my sin. But there arrived at length an epoch, from which the pleasurable feeling grew, by scarcely perceptible gradations, into a haunting and harassing thought. It harassed because it haunted. I could scarcely get rid of it for an instant. It is quite a common thing to be thus annoyed with the ringing in our ears, or rather in our memories, of the burthen of some ordinary song, or some unimpressive snatches from an opera. Nor will we be the less tormented if the song in itself be good, or the opera air meritorious. In this manner, at last, I would perpetually catch myself pondering upon my security, and repeating, in a low undertone, the phrase, "I am safe."  
  
One day, whilst sauntering along the streets, I arrested myself in the act of murmuring, half aloud, these customary syllables. In a fit of petulance, I remodelled them thus; "I am safe -- I am safe -- yes -- if I be not fool enough to make open confession!"  
  
No sooner had I spoken these words, than I felt an icy chill creep to my heart. I had had some experience in these fits of perversity, (whose nature I have been at some trouble to explain), and I remembered well that in no instance I had successfully resisted their attacks. And now my own casual self-suggestion that I might possibly be fool enough to confess the murder of which I had been guilty, confronted me, as if the very ghost of him whom I had murdered -- and beckoned me on to death.  
  
At first, I made an effort to shake off this nightmare of the soul. I walked vigorously -- faster -- still faster -- at length I ran. I felt a maddening desire to shriek aloud. Every succeeding wave of thought overwhelmed me with new terror, for, alas! I well, too well understood that to think, in my situation, was to be lost. I still quickened my pace. I bounded like a madman through the crowded thoroughfares. At length, the populace took the alarm, and pursued me. I felt then the consummation of my fate. Could I have torn out my tongue, I would have done it, but a rough voice resounded in my ears -- a rougher grasp seized me by the shoulder. I turned -- I gasped for breath. For a moment I experienced all the pangs of suffocation; I became blind, and deaf, and giddy; and then some invisible fiend, I thought, struck me with his broad palm upon the back. The long imprisoned secret burst forth from my soul.  
  
They say that I spoke with a distinct enunciation, but with marked emphasis and passionate hurry, as if in dread of interruption before concluding the brief, but pregnant sentences that consigned me to the hangman and to hell.  
  
Having related all that was necessary for the fullest judicial conviction, I fell prostrate in a swoon.  
  
But why shall I say more? To-day I wear these chains, and am here! To-morrow I shall be fetterless! -- but where?